Programmer Documentation — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »

# Programmer Documentation

This document is the technical reference for the GC3Libs programming model, aimed at programmers who want to use GC3Libs to implement computational workflows in Python.

The Programming overview section is the starting point for whoever wants to start developing applications with GC3Pie. It gives an overview of the main components of the library and how they interact with each other.

The Tutorials section contains documentation that describes in more detail the various components discussed in the programming overview, as well as many working examples (took from exercises done during the training events) and the Warholize Tutorial: a step-by-step tutorial that will show you how to write a complex GC3Pie workflow.

The GC3Libs programming API section instead contains the API reference of GC3Pie library.

- Programming overview
  - Computational job lifecycle
  - Managing jobs with GC3Libs
  - Execution model of GC3Libs applications
    - Application exit codes
    - Application execution states
    - Computational job specification
    - UML Diagram
- GC3Pie programming tutorials
  - Slides on specific topics
  - Example scripts
  - Warholize Tutorial
    - Introduction
    - From top to bottom
    - The script
    - The workflows
      - Main sequential workflow
      - Step one: convert to grayscale
    - Step two: parallel workflow to create colorized images
      - Step three: merge all them together
    - Making the script executable
    - Testing
- GC3Libs programming API
  - gc3libs
  - gc3libs.application
  - gc3libs.application.apppot
  - gc3libs.application.codeml
  - gc3libs.application.demo
  - gc3libs.application.gamess
  - gc3libs.application.rosetta
  - gc3libs.application.turbomole
  - gc3libs.authentication
  - gc3libs.authentication.grid
  - gc3libs.authentication.ssh
  - gc3libs.backends
  - gc3libs.backends.arc0
  - gc3libs.backends.arc1
  - gc3libs.backends.batch
  - gc3libs.backends.lsf
  - gc3libs.backends.pbs
  - gc3libs.backends.sge
  - gc3libs.backends.shellcmd
  - gc3libs.backends.slurm
  - gc3libs.backends.transport
  - gc3libs.cmdline
  - gc3libs.config
  - gc3libs.core
  - gc3libs.debug
  - gc3libs.exceptions
  - gc3libs.optimizer
  - gc3libs.optimizer.dif_evolution
  - gc3libs.optimizer.drivers
  - gc3libs.optimizer.extra
  - gc3libs.persistence
    - A usage warning
  - gc3libs.persistence.accessors
  - gc3libs.persistence.filesystem
  - gc3libs.persistence.idfactory
  - gc3libs.persistence.serialization
  - gc3libs.persistence.sql
  - gc3libs.persistence.store
  - gc3libs.quantity
  - gc3libs.session
  - gc3libs.template
  - gc3libs.url
  - gc3libs.utils
  - gc3libs.workflow
  - gc3utils
  - gc3utils.commands
  - gc3utils.frontend

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »